@@ -33,7 +33,7 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <libedata-book/e-book-backend-factory.h>
+#include <libedata-book/libedata-book.h>
 #include <libekolabutil/kolab-util-camel.h>
 
 #include "e-book-backend-kolab.h"
