@@ -29,15 +29,13 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <libedata-book/e-data-book-view.h>
-#include <libedata-book/e-book-backend-sync.h>
-#include <libedata-book/e-book-backend-cache.h>
-
 #include <libekolabutil/camel-system-headers.h>
 #include <libekolabutil/kolab-util-camel.h>
 #include <libekolabutil/kolab-util-http.h>
 #include <libekolabutil/kolab-util-glib.h>
 
+#include <libekolab/e-source-kolab-folder.h>
+#include <libekolab/camel-kolab-imapx-settings.h>
 #include <libekolab/kolab-types.h>
 #include <libekolab/kolab-mail-access.h>
 #include <libekolab/kolab-settings-handler.h>
@@ -51,8 +49,8 @@
 /* table of KolabMailAccess objects */
 
 static GHashTable *koma_objects = NULL;
-static GMutex *koma_objects_lock = NULL;
-static GMutex *active_book_views_lock = NULL;
+static GMutex koma_objects_lock;
+static GMutex active_book_views_lock;
 
 /*----------------------------------------------------------------------------*/
 
@@ -60,9 +58,7 @@ typedef struct _EBookBackendKolabPrivate EBookBackendKolabPrivate;
 struct _EBookBackendKolabPrivate
 {
 	/* GNOME_Evolution_Addressbook_BookMode	book_mode; */
-	EBookBackendCache *book_cache;
 	KolabMailAccess *book_koma;
-	gchar *book_uri;
 	gboolean auth_received;
 	GError *mode_switch_err;
 };
@@ -85,6 +81,36 @@ e_book_backend_kolab_open (EBookBackendSync *backend,
 /*----------------------------------------------------------------------------*/
 /* internal statics */
 
+static CamelKolabIMAPXSettings *
+book_backend_kolab_get_collection_settings (EBookBackendKolab *backend)
+{
+	ESource *source;
+	ESource *collection;
+	ESourceCamel *extension;
+	ESourceRegistry *registry;
+	CamelSettings *settings;
+	const gchar *extension_name;
+	const gchar *protocol;
+
+	source = e_backend_get_source (E_BACKEND (backend));
+	registry = e_book_backend_get_registry (E_BOOK_BACKEND (backend));
+
+	protocol = KOLAB_CAMEL_PROVIDER_PROTOCOL;
+	extension_name = e_source_camel_get_extension_name (protocol);
+	e_source_camel_generate_subtype (protocol, CAMEL_TYPE_KOLAB_IMAPX_SETTINGS);
+
+	/* The collection settings live in our parent data source. */
+	collection = e_source_registry_find_extension (registry, source, extension_name);
+	g_return_val_if_fail (collection != NULL, NULL);
+
+	extension = e_source_get_extension (collection, extension_name);
+	settings = e_source_camel_get_settings (extension);
+
+	g_object_unref (collection);
+
+	return CAMEL_KOLAB_IMAPX_SETTINGS (settings);
+}
+
 static void
 book_backend_kolab_signal_online_cb (GObject *object)
 {
@@ -206,17 +232,20 @@ e_book_backend_kolab_open (EBookBackendSync *backend,
 {
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
+	ESourceRegistry *registry;
 	ESource *esource = NULL;
-	CamelURL *c_url = NULL;
+	ESourceKolabFolder *extension;
+	CamelKolabIMAPXSettings *kolab_settings;
+	CamelNetworkSettings *network_settings;
 	KolabSettingsHandler *ksettings = NULL;
 	KolabMailAccess *tmp_koma = NULL;
 	KolabSyncStrategyID sync_value = KOLAB_SYNC_STRATEGY_DEFAULT;
-	gchar *sourcename = NULL;
+	const gchar *extension_name;
+	const gchar *foldername;
 	gchar *servername = NULL;
 	gchar *username = NULL;
 	gchar *user_at_server = NULL;
 	gchar *tmp_key = NULL;
-	const gchar *prop_str = NULL;
 	gboolean online = FALSE;
 	gboolean auth_required = FALSE;
 	gboolean ok = FALSE;
@@ -231,13 +260,9 @@ e_book_backend_kolab_open (EBookBackendSync *backend,
 	self = E_BOOK_BACKEND_KOLAB (backend);
 	priv = E_BOOK_BACKEND_KOLAB_PRIVATE (self);
 
-	g_mutex_lock (koma_objects_lock);
+	g_mutex_lock (&koma_objects_lock);
 
-	/* to trigger eds to pass along username and password, set the property
-	 * "auth" to "true" in the source setting:
-	 * <property name="auth" value="true"/>
-	 * <property name="username" value="..."/>
-	 */
+	registry = e_book_backend_get_registry (E_BOOK_BACKEND (backend));
 
 	esource = e_backend_get_source (E_BACKEND (backend));
 	if (! E_IS_SOURCE (esource)) {
@@ -247,28 +272,20 @@ e_book_backend_kolab_open (EBookBackendSync *backend,
 		goto exit;
 	}
 
-	priv->book_uri = e_source_get_uri (esource);
-	c_url = camel_url_new (priv->book_uri, &tmp_err);
-	if (c_url == NULL)
-		goto exit;
+	kolab_settings = book_backend_kolab_get_collection_settings (self);
+	network_settings = CAMEL_NETWORK_SETTINGS (kolab_settings);
 
-	servername = g_strdup (c_url->host);
-	username = g_strdup (c_url->user);
+	servername = camel_network_settings_dup_host (network_settings);
+	username = camel_network_settings_dup_user (network_settings);
 	g_debug ("%s()[%u] servername = %s", __func__, __LINE__, servername);
 	g_debug ("%s()[%u]   username = %s", __func__, __LINE__, username);
 
-	/* Initialize backend cache */
-	if (priv->book_cache != NULL) {
-		g_object_unref (priv->book_cache);
-	}
-	priv->book_cache = e_book_backend_cache_new (priv->book_uri);
-	ok = e_file_cache_clean (E_FILE_CACHE (priv->book_cache));
-	g_debug (" + Book cache cleaning %s.", ok ? "was successful" : "FAILED");
-
 	/* Prepare data from sync strategy property */
-	prop_str = e_source_get_property (esource, KOLAB_SYNC_STRATEGY_PROP);
-	sync_value = kolab_util_misc_sync_value_from_property (prop_str);
-	sourcename = kolab_util_backend_get_relative_path_from_uri (priv->book_uri);
+	extension_name = E_SOURCE_EXTENSION_KOLAB_FOLDER;
+	extension = e_source_get_extension (esource, extension_name);
+	sync_value = e_source_kolab_folder_get_sync_strategy (extension);
+
+	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
 	/* Check whether we have a KolabMailAccess (KoMA) instance already */
 	user_at_server = g_strdup_printf ("%s@%s",
@@ -290,9 +307,7 @@ e_book_backend_kolab_open (EBookBackendSync *backend,
 		kolab_util_backend_prepare_settings (ksettings,
 		                                     NULL,
 		                                     NULL,
-		                                     NULL,
-		                                     NULL,
-		                                     sourcename,
+		                                     foldername,
 		                                     &sync_value);
 		/* We may find that we do not yet have a password set.
 		 * In case we're requested to go online, we will need
@@ -329,7 +344,7 @@ e_book_backend_kolab_open (EBookBackendSync *backend,
 		goto exit;
 
 	/* Configure settings handler */
-	ksettings = KOLAB_SETTINGS_HANDLER (g_object_new (KOLAB_TYPE_SETTINGS_HANDLER, NULL));
+	ksettings = kolab_settings_handler_new (kolab_settings);
 	ok = kolab_settings_handler_configure (ksettings,
 	                                       KOLAB_FOLDER_CONTEXT_CONTACT,
 	                                       &tmp_err);
@@ -342,10 +357,8 @@ e_book_backend_kolab_open (EBookBackendSync *backend,
 
 	kolab_util_backend_prepare_settings (ksettings,
 	                                     esource,
-	                                     servername,
-	                                     username,
 	                                     NULL,
-	                                     sourcename,
+	                                     foldername,
 	                                     &sync_value);
 
 	/* create new KolabMailAccess instance */
@@ -384,10 +397,8 @@ e_book_backend_kolab_open (EBookBackendSync *backend,
 	if (ksettings != NULL)
 		g_object_unref (ksettings);
 
-	g_mutex_unlock (koma_objects_lock);
+	g_mutex_unlock (&koma_objects_lock);
 
-	if (c_url != NULL)
-		camel_url_free (c_url);
 	if (servername != NULL)
 		g_free (servername);
 	if (username != NULL)
@@ -402,10 +413,16 @@ e_book_backend_kolab_open (EBookBackendSync *backend,
 		return;
 	}
 
-	/* do we need authentication data? if so, notify and return */
+	/* authenticate now if required */
 	if (auth_required) {
-		e_book_backend_notify_auth_required (E_BOOK_BACKEND (self), TRUE, NULL);
-		return;
+		ESourceAuthenticator *authenticator;
+
+		authenticator = E_SOURCE_AUTHENTICATOR (priv->book_koma);
+
+		ok = e_source_registry_authenticate_sync (
+			registry, esource, authenticator, cancellable, error);
+		if (!ok)
+			return;
 	}
 
 	/* all good, notify that we're open for business */
@@ -442,13 +459,6 @@ e_book_backend_kolab_remove (EBookBackendSync *backend,
 		priv->book_koma = NULL;
 	}
 
-	/* Removing backend cache */
-	if (priv->book_cache != NULL) {
-		(void) e_file_cache_remove (E_FILE_CACHE (priv->book_cache));
-		g_object_unref (priv->book_cache);
-		priv->book_cache = NULL;
-	}
-
 	e_book_backend_set_is_writable (E_BOOK_BACKEND (backend), FALSE);
 	e_book_backend_notify_writable (E_BOOK_BACKEND (backend), FALSE);
 	e_book_backend_notify_connection_status (E_BOOK_BACKEND (backend), FALSE);
@@ -568,10 +578,9 @@ e_book_backend_kolab_create_contacts (EBookBackendSync *backend,
 			goto exit;
 		}
 
-		ok = kolab_util_contact_cache_assure_uid_on_econtact (priv->book_cache,
+		ok = kolab_util_contact_cache_assure_uid_on_econtact (backend,
 		                                                      priv->book_koma,
 		                                                      econtact,
-		                                                      priv->book_uri,
 		                                                      FALSE,
 		                                                      cancellable,
 		                                                      &tmp_err);
@@ -579,8 +588,8 @@ e_book_backend_kolab_create_contacts (EBookBackendSync *backend,
 			goto exit;
 
 		ok = kolab_util_contact_store (econtact,
+		                               backend,
 		                               priv->book_koma,
-		                               priv->book_uri,
 		                               cancellable,
 		                               &tmp_err);
 		if (! ok)
@@ -610,7 +619,7 @@ e_book_backend_kolab_remove_contacts (EBookBackendSync *backend,
 	EBookBackendKolab *self = NULL;
 	EBookBackendKolabPrivate *priv = NULL;
 	const GSList *it = NULL;
-	gchar *sourcename = NULL;
+	const gchar *foldername;
 	gboolean ok = FALSE;
 	GError *tmp_err = NULL;
 
@@ -624,13 +633,13 @@ e_book_backend_kolab_remove_contacts (EBookBackendSync *backend,
 	self = E_BOOK_BACKEND_KOLAB (backend);
 	priv = E_BOOK_BACKEND_KOLAB_PRIVATE (self);
 
-	sourcename = kolab_util_backend_get_relative_path_from_uri (priv->book_uri);
+	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
 	for (it = id_list; it != NULL; it = g_slist_next (it)) {
 		const gchar *uid = it->data;
 		ok = kolab_mail_access_delete_by_uid (priv->book_koma,
 		                                      uid,
-		                                      sourcename,
+		                                      foldername,
 		                                      cancellable,
 		                                      &tmp_err);
 		if (! ok) {
@@ -646,8 +655,6 @@ e_book_backend_kolab_remove_contacts (EBookBackendSync *backend,
 	}
 
  exit:
-	g_free (sourcename);
-
 	if (tmp_err != NULL) {
 		kolab_util_contact_err_to_edb_err (error, tmp_err, __func__, __LINE__);
 		g_error_free (tmp_err);
@@ -691,8 +698,8 @@ e_book_backend_kolab_modify_contacts (EBookBackendSync *backend,
 		}
 
 		ok = kolab_util_contact_store (econtact,
+		                               backend,
 		                               priv->book_koma,
-		                               priv->book_uri,
 		                               cancellable,
 		                               &tmp_err);
 		if (! ok)
@@ -736,9 +743,8 @@ e_book_backend_kolab_get_contact (EBookBackendSync *backend,
 
 	g_debug ("%s()[%u] called.", __func__, __LINE__);
 
-	econtact = kolab_util_contact_cache_get_object (priv->book_cache,
+	econtact = kolab_util_contact_cache_get_object (backend,
 	                                                priv->book_koma,
-	                                                priv->book_uri,
 	                                                id,
 	                                                FALSE,
 	                                                cancellable,
@@ -783,10 +789,9 @@ e_book_backend_kolab_get_contact_list (EBookBackendSync *backend,
 	g_debug (" + query: %s", query);
 
 	/* Update the cache to contain all data requested. */
-	ok = kolab_util_contact_cache_update_on_query (priv->book_cache,
+	ok = kolab_util_contact_cache_update_on_query (backend,
 	                                               priv->book_koma,
 	                                               query,
-	                                               priv->book_uri,
 	                                               cancellable,
 	                                               &tmp_err);
 	if (! ok) {
@@ -796,10 +801,9 @@ e_book_backend_kolab_get_contact_list (EBookBackendSync *backend,
 	}
 
 	/* Fetch information from BackendCache */;
-	econtact_list = kolab_util_contact_cache_get_contacts (priv->book_cache,
+	econtact_list = kolab_util_contact_cache_get_contacts (backend,
 	                                                       priv->book_koma,
 	                                                       query,
-	                                                       priv->book_uri,
 	                                                       cancellable,
 	                                                       &tmp_err);
 	if (tmp_err != NULL) {
@@ -858,10 +862,9 @@ e_book_backend_kolab_get_contact_list_uids (EBookBackendSync *backend,
 	 */
 
 	/* Update the cache to contain all data requested. */
-	ok = kolab_util_contact_cache_update_on_query (priv->book_cache,
+	ok = kolab_util_contact_cache_update_on_query (backend,
 	                                               priv->book_koma,
 	                                               query,
-	                                               priv->book_uri,
 	                                               cancellable,
 	                                               &tmp_err);
 	if (! ok) {
@@ -871,10 +874,9 @@ e_book_backend_kolab_get_contact_list_uids (EBookBackendSync *backend,
 	}
 
 	/* Fetch information from BackendCache */;
-	econtact_list = kolab_util_contact_cache_get_contacts (priv->book_cache,
+	econtact_list = kolab_util_contact_cache_get_contacts (backend,
 	                                                       priv->book_koma,
 	                                                       query,
-	                                                       priv->book_uri,
 	                                                       cancellable,
 	                                                       &tmp_err);
 	if (tmp_err != NULL) {
@@ -939,6 +941,8 @@ e_book_backend_kolab_get_backend_property (EBookBackendSync *backend,
 	return processed;
 }
 
+#if 0  /* FIXME Delete this once kolab_mail_access_try_password_sync()
+        *       works.  There may be code here that can be reused. */
 static void
 e_book_backend_kolab_authenticate_user (EBookBackendSync *backend,
                                         GCancellable *cancellable,
@@ -1043,7 +1047,6 @@ e_book_backend_kolab_authenticate_user (EBookBackendSync *backend,
 		g_warning (" + username from argument and username in "
 		           "KolabSettingsHandler do not match: %s vs. %s",
 		           tmp_user, user);
-	sourcename = kolab_util_backend_get_relative_path_from_uri (priv->book_uri);
 
 	kolab_util_backend_prepare_settings (ksettings,
 	                                     NULL,
@@ -1060,6 +1063,7 @@ e_book_backend_kolab_authenticate_user (EBookBackendSync *backend,
 	return GNOME_Evolution_Addressbook_Success;
 #endif /* FIXME */
 }
+#endif
 
 static void
 e_book_backend_kolab_start_book_view (EBookBackend *backend,
@@ -1080,26 +1084,24 @@ e_book_backend_kolab_start_book_view (EBookBackend *backend,
 	self = E_BOOK_BACKEND_KOLAB (backend);
 	priv = E_BOOK_BACKEND_KOLAB_PRIVATE (self);
 
-	g_mutex_lock (active_book_views_lock);
+	g_mutex_lock (&active_book_views_lock);
 
 	g_object_ref (book_view); /* unref()d in stop_view() */
 
 	query = e_data_book_view_get_card_query (book_view);
 
 	/* First update the BackendCache to the current situation. */
-	ok = kolab_util_contact_cache_update_on_query (priv->book_cache,
+	ok = kolab_util_contact_cache_update_on_query (E_BOOK_BACKEND_SYNC (backend),
 	                                               priv->book_koma,
 	                                               query,
-	                                               priv->book_uri,
 	                                               NULL, /* FIXME GCancellable */
 	                                               &tmp_err);
 	if (! ok)
 		goto exit;
 
-	econtact_list = kolab_util_contact_cache_get_contacts (priv->book_cache,
+	econtact_list = kolab_util_contact_cache_get_contacts (E_BOOK_BACKEND_SYNC (backend),
 	                                                       priv->book_koma,
 	                                                       query,
-	                                                       priv->book_uri,
 	                                                       NULL, /* FIXME GCancellable */
 	                                                       &tmp_err);
 	if (tmp_err != NULL)
@@ -1121,7 +1123,7 @@ e_book_backend_kolab_start_book_view (EBookBackend *backend,
 
 	e_data_book_view_notify_complete (book_view, notify_err);
 
-	g_mutex_unlock (active_book_views_lock);
+	g_mutex_unlock (&active_book_views_lock);
 
 	if (notify_err != NULL)
 		g_error_free (notify_err);
@@ -1145,13 +1147,13 @@ e_book_backend_kolab_stop_book_view (EBookBackend *backend,
 	self = E_BOOK_BACKEND_KOLAB (backend);
 	priv = E_BOOK_BACKEND_KOLAB_PRIVATE (self);
 
-	g_mutex_lock (active_book_views_lock);
+	g_mutex_lock (&active_book_views_lock);
 
 	e_data_book_view_notify_complete (book_view, NULL);
 
 	g_object_unref (book_view); /* ref()d in start_view() */
 
-	g_mutex_unlock (active_book_views_lock);
+	g_mutex_unlock (&active_book_views_lock);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -1162,38 +1164,16 @@ e_book_backend_kolab_init (EBookBackendKolab *backend)
 {
 	EBookBackendKolabPrivate *priv = E_BOOK_BACKEND_KOLAB_PRIVATE (backend);
 
-	/* We're inside a thread, and each of our siblings
-	 * (other configured ECalBackendKolab instances) is
-	 * so as well. Depending on how the threads are
-	 * started, checking for lock existence (and creating
-	 * one if it is not) in *this* place can still be
-	 * racy. Let's hope the threads are started one
-	 * at a time, in which case this solution will work.
-	 * The whole handling of living KolabMailAccess
-	 * instances would better be moved to a separate
-	 * library...
-	 *
-	 */
-	if (koma_objects_lock == NULL)
-		koma_objects_lock = g_mutex_new ();
-	g_mutex_lock (koma_objects_lock);
+	g_mutex_lock (&koma_objects_lock);
 	if (koma_objects == NULL)
 		koma_objects = g_hash_table_new_full (g_direct_hash,
 		                                      g_direct_equal,
 		                                      g_free,
 		                                      g_object_unref);
-	g_mutex_unlock (koma_objects_lock);
-	/* active cal views are shared in the same way,
-	 * so we do the locking for them analogous
-	 * to the KolabMailAccess instances
-	 */
-	if (active_book_views_lock == NULL)
-		active_book_views_lock = g_mutex_new ();
+	g_mutex_unlock (&koma_objects_lock);
 
 	g_debug ("%s()[%u] called.", __func__, __LINE__);
 
-	priv->book_cache = NULL;
-	priv->book_uri = NULL;
 	priv->book_koma = NULL;
 	priv->auth_received = FALSE;
 	priv->mode_switch_err = NULL;
@@ -1224,11 +1204,6 @@ e_book_backend_kolab_dispose (GObject *object)
 		priv->book_koma = NULL;
 	}
 #endif
-	if (priv->book_cache != NULL) {
-		(void) e_file_cache_remove (E_FILE_CACHE (priv->book_cache));
-		g_object_unref (priv->book_cache);
-		priv->book_cache = NULL;
-	}
 }
 
 static void
@@ -1238,8 +1213,6 @@ e_book_backend_kolab_finalize (GObject *object)
 
 	g_debug ("%s()[%u] called.", __func__, __LINE__);
 
-	if (priv->book_uri != NULL)
-		g_free (priv->book_uri);
 	if (priv->mode_switch_err != NULL) {
 		g_warning ("%s()[%u]: %s",
 		           __func__, __LINE__, priv->mode_switch_err->message);
@@ -1281,7 +1254,6 @@ e_book_backend_kolab_class_init (EBookBackendKolabClass *klass)
 	sync_class->get_contact_sync = e_book_backend_kolab_get_contact;
 	sync_class->get_contact_list_sync = e_book_backend_kolab_get_contact_list;
 	sync_class->get_contact_list_uids_sync = e_book_backend_kolab_get_contact_list_uids;
-	sync_class->authenticate_user_sync = e_book_backend_kolab_authenticate_user;
 } /* e_book_backend_kolab_class_init () */
 
 
