@@ -29,12 +29,12 @@
 #include <glib.h>
 #include <gio/gio.h>
 
-#include <libedata-cal/e-cal-backend-cache.h>
-#include <libedata-cal/e-data-cal-types.h>
-#include <libecal/e-cal.h>
+#include <libecal/libecal.h>
 
 #include <libical/ical.h>
 
+#include <libekolab/e-source-kolab-folder.h>
+#include <libekolab/camel-kolab-imapx-settings.h>
 #include <libekolab/kolab-mail-access.h>
 #include <libekolab/kolab-settings-handler.h>
 #include <libekolab/kolab-mail-handle.h>
@@ -51,8 +51,8 @@
 /* table of KolabMailAccess objects */
 
 static GHashTable *koma_objects = NULL;
-static GMutex *koma_objects_lock = NULL;
-static GMutex *active_cal_views_lock = NULL;
+static GMutex koma_objects_lock;
+static GMutex active_cal_views_lock;
 
 /*----------------------------------------------------------------------------*/
 /* forward declarations */
@@ -79,14 +79,6 @@ G_DEFINE_TYPE (ECalBackendKolab, e_cal_backend_kolab, E_TYPE_CAL_BACKEND_SYNC)
 
 /* private structures for Kolab calendar class ********************************/
 
-/* TODO check what is appropriate for Kolab here */
-
-typedef struct {
-	GCond *cond;
-	GMutex *mutex;
-	gboolean exit;
-} SyncDelta;
-
 /* Private part of the ECalBackendKolab structure */
 typedef struct _ECalBackendKolabPrivate ECalBackendKolabPrivate;
 struct _ECalBackendKolabPrivate {
@@ -96,13 +88,42 @@ struct _ECalBackendKolabPrivate {
 	gchar *user_email;
 	ECalComponent *default_zone;
 	ECalSourceType source_type;
-	gchar *cal_uri;
 	GError *mode_switch_err;
 };
 
 /*----------------------------------------------------------------------------*/
 /* internal statics */
 
+static CamelKolabIMAPXSettings *
+cal_backend_kolab_get_collection_settings (ECalBackendKolab *backend)
+{
+	ESource *source;
+	ESource *collection;
+	ESourceCamel *extension;
+	ESourceRegistry *registry;
+	CamelSettings *settings;
+	const gchar *extension_name;
+	const gchar *protocol;
+
+	source = e_backend_get_source (E_BACKEND (backend));
+	registry = e_cal_backend_get_registry (E_CAL_BACKEND (backend));
+
+	protocol = KOLAB_CAMEL_PROVIDER_PROTOCOL;
+	extension_name = e_source_camel_get_extension_name (protocol);
+	e_source_camel_generate_subtype (protocol, CAMEL_TYPE_KOLAB_IMAPX_SETTINGS);
+
+	/* The collection settings live in our parent data source. */
+	collection = e_source_registry_find_extension (registry, source, extension_name);
+	g_return_val_if_fail (collection != NULL, NULL);
+
+	extension = e_source_get_extension (collection, extension_name);
+	settings = e_source_camel_get_settings (extension);
+
+	g_object_unref (collection);
+
+	return CAMEL_KOLAB_IMAPX_SETTINGS (settings);
+}
+
 static void
 cal_backend_kolab_signal_online_cb (GObject *object)
 {
@@ -235,18 +256,23 @@ e_cal_backend_kolab_open (ECalBackendSync *backend,
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
+	ESourceRegistry *registry;
 	ESource *esource = NULL;
-	CamelURL *c_url = NULL;
+	ESourceKolabFolder *extension;
+	CamelKolabIMAPXSettings *kolab_settings;
+	CamelNetworkSettings *network_settings;
 	KolabSettingsHandler *ksettings = NULL;
 	KolabMailAccess *tmp_koma = NULL;
 	KolabSyncStrategyID sync_value = KOLAB_SYNC_STRATEGY_DEFAULT;
 	icalcomponent_kind icalkind = ICAL_VEVENT_COMPONENT;
-	gchar *sourcename = NULL;
+	const gchar *extension_name;
+	const gchar *foldername;
+	const gchar *cache_dir;
+	gchar *cache_filename;
 	gchar *servername = NULL;
 	gchar *username = NULL;
 	gchar *user_at_server = NULL;
 	gchar *tmp_key = NULL;
-	const gchar *prop_str = NULL;
 	gboolean online = FALSE;
 	gboolean auth_required = FALSE;
 	gboolean ok = FALSE;
@@ -261,13 +287,9 @@ e_cal_backend_kolab_open (ECalBackendSync *backend,
 	self = E_CAL_BACKEND_KOLAB (backend);
 	priv = E_CAL_BACKEND_KOLAB_PRIVATE (self);
 
-	g_mutex_lock (koma_objects_lock);
+	g_mutex_lock (&koma_objects_lock);
 
-	/* to trigger eds to pass along username and password, set the property
-	 * "auth" to "true" in the source setting:
-	 * <property name="auth" value="true"/>
-	 * <property name="username" value="..."/>
-	 */
+	registry = e_cal_backend_get_registry (E_CAL_BACKEND (backend));
 
 	icalkind = e_cal_backend_get_kind (E_CAL_BACKEND (backend));
 	/* TODO: this has to be set according to the get_kind() method */
@@ -297,13 +319,11 @@ e_cal_backend_kolab_open (ECalBackendSync *backend,
 		goto exit;
 	}
 
-	priv->cal_uri = e_source_get_uri (esource);
-	c_url = camel_url_new (priv->cal_uri, &tmp_err);
-	if (c_url == NULL)
-		goto exit;
+	kolab_settings = cal_backend_kolab_get_collection_settings (self);
+	network_settings = CAMEL_NETWORK_SETTINGS (kolab_settings);
 
-	servername = g_strdup (c_url->host);
-	username = g_strdup (c_url->user);
+	servername = camel_network_settings_dup_host (network_settings);
+	username = camel_network_settings_dup_user (network_settings);
 	g_debug ("%s()[%u] servername = %s", __func__, __LINE__, servername);
 	g_debug ("%s()[%u]   username = %s", __func__, __LINE__, username);
 
@@ -311,14 +331,21 @@ e_cal_backend_kolab_open (ECalBackendSync *backend,
 	if (priv->cal_cache != NULL) {
 		g_object_unref (priv->cal_cache);
 	}
-	priv->cal_cache = e_cal_backend_cache_new (priv->cal_uri);
+
+	cache_dir = e_cal_backend_get_cache_dir (E_CAL_BACKEND (backend));
+	cache_filename = g_build_filename (cache_dir, "cache.xml", NULL);
+	priv->cal_cache = e_cal_backend_cache_new (cache_filename);
+	g_free (cache_filename);
+
 	ok = e_file_cache_clean (E_FILE_CACHE (priv->cal_cache));
 	g_debug (" + Cal cache cleaning %s.", ok ? "was successful" : "FAILED");
 
 	/* Prepare data from sync strategy property */
-	prop_str = e_source_get_property (esource, KOLAB_SYNC_STRATEGY_PROP);
-	sync_value = kolab_util_misc_sync_value_from_property (prop_str);
-	sourcename = kolab_util_backend_get_relative_path_from_uri (priv->cal_uri);
+	extension_name = E_SOURCE_EXTENSION_KOLAB_FOLDER;
+	extension = e_source_get_extension (esource, extension_name);
+	sync_value = e_source_kolab_folder_get_sync_strategy (extension);
+
+	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
 	/* Check whether we have a KolabMailAccess (KoMA) instance already */
 	user_at_server = g_strdup_printf ("%s@%s",
@@ -340,9 +367,7 @@ e_cal_backend_kolab_open (ECalBackendSync *backend,
 		kolab_util_backend_prepare_settings (ksettings,
 		                                     NULL,
 		                                     NULL,
-		                                     NULL,
-		                                     NULL,
-		                                     sourcename,
+		                                     foldername,
 		                                     &sync_value);
 		/* We may find that we do not yet have a password set.
 		 * In case we're requested to go online, we will need
@@ -379,7 +404,7 @@ e_cal_backend_kolab_open (ECalBackendSync *backend,
 		goto exit;
 
 	/* Configure settings handler */
-	ksettings = KOLAB_SETTINGS_HANDLER (g_object_new (KOLAB_TYPE_SETTINGS_HANDLER, NULL));
+	ksettings = kolab_settings_handler_new (kolab_settings);
 	ok = kolab_settings_handler_configure (ksettings,
 	                                       KOLAB_FOLDER_CONTEXT_CALENDAR,
 	                                       &tmp_err);
@@ -392,10 +417,8 @@ e_cal_backend_kolab_open (ECalBackendSync *backend,
 
 	kolab_util_backend_prepare_settings (ksettings,
 	                                     esource,
-	                                     servername,
-	                                     username,
 	                                     NULL,
-	                                     sourcename,
+	                                     foldername,
 	                                     &sync_value);
 
 	/* create new KolabMailAccess instance */
@@ -440,10 +463,8 @@ e_cal_backend_kolab_open (ECalBackendSync *backend,
 	if (ksettings != NULL)
 		g_object_unref (ksettings);
 
-	g_mutex_unlock (koma_objects_lock);
+	g_mutex_unlock (&koma_objects_lock);
 
-	if (c_url != NULL)
-		camel_url_free (c_url);
 	if (servername != NULL)
 		g_free (servername);
 	if (username != NULL)
@@ -458,10 +479,16 @@ e_cal_backend_kolab_open (ECalBackendSync *backend,
 		return;
 	}
 
-	/* do we need authentication data? if so, notify and return */
+	/* authenticate now if required */
 	if (auth_required) {
-		e_cal_backend_notify_auth_required (E_CAL_BACKEND (self), TRUE, NULL);
-		return;
+		ESourceAuthenticator *authenticator;
+
+		authenticator = E_SOURCE_AUTHENTICATOR (priv->cal_koma);
+
+		ok = e_source_registry_authenticate_sync (
+			registry, esource, authenticator, cancellable, error);
+		if (!ok)
+			return;
 	}
 
 	/* all good, notify that we're open for business */
@@ -672,9 +699,9 @@ e_cal_backend_kolab_get_object (ECalBackendSync *backend,
 	self = E_CAL_BACKEND_KOLAB (backend);
 	priv = E_CAL_BACKEND_KOLAB_PRIVATE (self);
 
-	ecalcomp = kolab_util_calendar_cache_get_object (priv->cal_cache,
+	ecalcomp = kolab_util_calendar_cache_get_object (backend,
+	                                                 priv->cal_cache,
 	                                                 priv->cal_koma,
-	                                                 priv->cal_uri,
 	                                                 uid,
 	                                                 FALSE,
 	                                                 cancellable,
@@ -702,7 +729,7 @@ e_cal_backend_kolab_get_object_list (ECalBackendSync *backend,
 	ECalBackendKolabPrivate *priv = NULL;
 	GList *uid_list = NULL;
 	GList *it = NULL;
-	gchar *sourcename = NULL;
+	const gchar *foldername;
 	gboolean ok = FALSE;
 	GError *tmp_err = NULL;
 
@@ -716,10 +743,10 @@ e_cal_backend_kolab_get_object_list (ECalBackendSync *backend,
 	self = E_CAL_BACKEND_KOLAB (backend);
 	priv = E_CAL_BACKEND_KOLAB_PRIVATE (self);
 
-	ok = kolab_util_calendar_cache_update_on_query (priv->cal_cache,
+	ok = kolab_util_calendar_cache_update_on_query (backend,
+	                                                priv->cal_cache,
 	                                                priv->cal_koma,
 	                                                sexp,
-	                                                priv->cal_uri,
 	                                                cancellable,
 	                                                &tmp_err);
 	if (! ok) {
@@ -728,12 +755,11 @@ e_cal_backend_kolab_get_object_list (ECalBackendSync *backend,
 		return;
 	}
 
-	sourcename = kolab_util_backend_get_relative_path_from_uri (priv->cal_uri);
+	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 	uid_list = kolab_mail_access_query_uids (priv->cal_koma,
-	                                         sourcename,
+	                                         foldername,
 	                                         sexp,
 	                                         &tmp_err);
-	g_free (sourcename);
 	if (tmp_err != NULL) {
 		kolab_util_calendar_err_to_edb_err (error, tmp_err, __func__, __LINE__);
 		g_error_free (tmp_err);
@@ -743,9 +769,9 @@ e_cal_backend_kolab_get_object_list (ECalBackendSync *backend,
 	for (it = uid_list; it != NULL; it = g_list_next (it)) {
 		gchar *uid = it->data;
 		ECalComponent *ecalcomp = NULL;
-		ecalcomp = kolab_util_calendar_cache_get_object (priv->cal_cache,
+		ecalcomp = kolab_util_calendar_cache_get_object (backend,
+		                                                 priv->cal_cache,
 		                                                 priv->cal_koma,
-		                                                 priv->cal_uri,
 		                                                 uid,
 		                                                 TRUE,
 		                                                 cancellable,
@@ -951,10 +977,10 @@ e_cal_backend_kolab_create_objects (ECalBackendSync *backend,
 		}
 	}
 
-	ok = kolab_util_calendar_cache_assure_uid_on_ecalcomponent (priv->cal_cache,
+	ok = kolab_util_calendar_cache_assure_uid_on_ecalcomponent (backend,
+	                                                            priv->cal_cache,
 	                                                            priv->cal_koma,
 	                                                            ecalcomp,
-	                                                            priv->cal_uri,
 	                                                            FALSE,
 	                                                            cancellable,
 	                                                            &tmp_err);
@@ -970,8 +996,8 @@ e_cal_backend_kolab_create_objects (ECalBackendSync *backend,
 	ok = kolab_util_calendar_store (ecalcomp,
 	                                tzcomp,
 	                                priv->default_zone,
+	                                backend,
 	                                priv->cal_koma,
-	                                priv->cal_uri,
 	                                cancellable,
 	                                &tmp_err);
 	if (! ok) {
@@ -1078,9 +1104,9 @@ e_cal_backend_kolab_modify_objects (ECalBackendSync *backend,
 
 	e_cal_component_get_uid (ecalcomp, &uid);
 
-	oldcomp = kolab_util_calendar_cache_get_object (priv->cal_cache,
+	oldcomp = kolab_util_calendar_cache_get_object (backend,
+	                                                priv->cal_cache,
 	                                                priv->cal_koma,
-	                                                priv->cal_uri,
 	                                                uid,
 	                                                FALSE,
 	                                                cancellable,
@@ -1121,10 +1147,10 @@ e_cal_backend_kolab_modify_objects (ECalBackendSync *backend,
 		                                                     oldcomp,
 		                                                     uid,
 		                                                     rid);
-		ok = kolab_util_calendar_cache_assure_uid_on_ecalcomponent (priv->cal_cache,
+		ok = kolab_util_calendar_cache_assure_uid_on_ecalcomponent (backend,
+		                                                            priv->cal_cache,
 		                                                            priv->cal_koma,
 		                                                            ecalcomp,
-		                                                            priv->cal_uri,
 		                                                            TRUE,
 		                                                            cancellable,
 		                                                            &tmp_err);
@@ -1146,8 +1172,8 @@ e_cal_backend_kolab_modify_objects (ECalBackendSync *backend,
 		ok = kolab_util_calendar_store (newcomp,
 		                                oldtz,
 		                                priv->default_zone,
+		                                backend,
 		                                priv->cal_koma,
-		                                priv->cal_uri,
 		                                cancellable,
 		                                &tmp_err);
 		if (! ok) {
@@ -1174,8 +1200,8 @@ e_cal_backend_kolab_modify_objects (ECalBackendSync *backend,
 	ok = kolab_util_calendar_store (ecalcomp,
 	                                ecaltz,
 	                                priv->default_zone,
+	                                backend,
 	                                priv->cal_koma,
-	                                priv->cal_uri,
 	                                cancellable,
 	                                &tmp_err);
 	if (! ok) {
@@ -1230,7 +1256,7 @@ e_cal_backend_kolab_remove_objects (ECalBackendSync *backend,
 	ECalComponentId *id = NULL;
 	const gchar *uid, *rid;
 	KolabSettingsHandler *ksettings = NULL;
-	gchar *sourcename = NULL;
+	const gchar *foldername;
 	GError *tmp_err = NULL;
 	gboolean trigger_needed = FALSE;
 	gboolean ok = FALSE;
@@ -1260,9 +1286,11 @@ e_cal_backend_kolab_remove_objects (ECalBackendSync *backend,
 	if (rid == NULL)
 		mod = CALOBJ_MOD_ALL;
 
-	oldcomp = kolab_util_calendar_cache_get_object (priv->cal_cache,
+	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
+
+	oldcomp = kolab_util_calendar_cache_get_object (backend,
+	                                                priv->cal_cache,
 	                                                priv->cal_koma,
-	                                                priv->cal_uri,
 	                                                uid,
 	                                                FALSE,
 	                                                cancellable,
@@ -1306,8 +1334,8 @@ e_cal_backend_kolab_remove_objects (ECalBackendSync *backend,
 		ok = kolab_util_calendar_store (newcomp,
 		                                oldtz,
 		                                priv->default_zone,
+		                                backend,
 		                                priv->cal_koma,
-		                                priv->cal_uri,
 		                                cancellable,
 		                                &tmp_err);
 		if (oldtz != NULL)
@@ -1334,13 +1362,11 @@ e_cal_backend_kolab_remove_objects (ECalBackendSync *backend,
 		break;
 	case CALOBJ_MOD_ALL:
 	default:
-		sourcename = kolab_util_backend_get_relative_path_from_uri (priv->cal_uri);
 		ok = kolab_mail_access_delete_by_uid (priv->cal_koma,
 		                                      uid,
-		                                      sourcename,
+		                                      foldername,
 		                                      cancellable,
 		                                      &tmp_err);
-		g_free (sourcename);
 		(void) e_cal_backend_cache_remove_component (priv->cal_cache,
 		                                             uid,
 		                                             NULL);
@@ -1355,15 +1381,13 @@ e_cal_backend_kolab_remove_objects (ECalBackendSync *backend,
 		}
 	}
 
-	sourcename = kolab_util_backend_get_relative_path_from_uri (priv->cal_uri);
 	trigger_needed = kolab_mail_access_source_fbtrigger_needed (priv->cal_koma,
-	                                                            sourcename,
+	                                                            foldername,
 	                                                            &tmp_err);
 	if (tmp_err != NULL) {
 		kolab_util_calendar_err_to_edb_err (error, tmp_err, __func__, __LINE__);
 		g_error_free (tmp_err);
 		e_cal_component_free_id (id);
-		g_free (sourcename);
 		g_object_unref (oldcomp);
 		g_slist_free (*old_components);
 		*old_components = NULL;
@@ -1372,7 +1396,7 @@ e_cal_backend_kolab_remove_objects (ECalBackendSync *backend,
 	if (trigger_needed) {
 		ksettings = kolab_mail_access_get_settings_handler (priv->cal_koma);
 		ok = kolab_util_calendar_toggle_pfb_trigger (ksettings,
-		                                             sourcename,
+		                                             foldername,
 		                                             &tmp_err);
 		g_object_unref (ksettings);
 		if (! ok) {
@@ -1468,8 +1492,8 @@ e_cal_backend_kolab_receive_objects (ECalBackendSync *backend,
 	ok = kolab_util_calendar_store (ecalcomp,
 	                                tzcomp,
 	                                priv->default_zone,
+	                                backend,
 	                                priv->cal_koma,
-	                                priv->cal_uri,
 	                                cancellable,
 	                                &tmp_err);
 	if (! ok) {
@@ -1678,6 +1702,8 @@ e_cal_backend_kolab_add_timezone (ECalBackendSync *backend,
 	}
 }
 
+#if 0  /* FIXME Delete this once kolab_mail_access_try_password_sync()
+        *       works.  There may be code here that can be reused. */
 static void
 e_cal_backend_kolab_authenticate_user (ECalBackendSync *backend,
                                        GCancellable *cancellable,
@@ -1753,6 +1779,7 @@ e_cal_backend_kolab_authenticate_user (ECalBackendSync *backend,
 		g_error_free (tmp_err);
 	}
 }
+#endif
 
 /**
  * e_cal_backend_kolab_start_view:
@@ -1771,7 +1798,7 @@ e_cal_backend_kolab_start_view (ECalBackend *backend,
 	GList *it = NULL;
 	GSList *iCal_objects = NULL;
 	const gchar *query = NULL;
-	gchar *sourcename = NULL;
+	const gchar *foldername;
 	GError *tmp_err = NULL;
 	GError *view_err = NULL;
 	gboolean ok = FALSE;
@@ -1782,25 +1809,25 @@ e_cal_backend_kolab_start_view (ECalBackend *backend,
 	self = E_CAL_BACKEND_KOLAB (backend);
 	priv = E_CAL_BACKEND_KOLAB_PRIVATE (self);
 
-	g_mutex_lock (active_cal_views_lock);
+	g_mutex_lock (&active_cal_views_lock);
 
 	g_object_ref (view); /* unref()d in stop_view() */
 
 	query = e_data_cal_view_get_text (view);
 
-	sourcename = kolab_util_backend_get_relative_path_from_uri (priv->cal_uri);
+	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
-	ok = kolab_util_calendar_cache_update_on_query (priv->cal_cache,
+	ok = kolab_util_calendar_cache_update_on_query (E_CAL_BACKEND_SYNC (backend),
+	                                                priv->cal_cache,
 	                                                priv->cal_koma,
 	                                                query,
-	                                                priv->cal_uri,
 	                                                NULL, /* FIXME: GCancellable */
 	                                                &tmp_err);
 	if (! ok)
 		goto exit;
 
 	uid_list = kolab_mail_access_query_uids (priv->cal_koma,
-	                                         sourcename,
+	                                         foldername,
 	                                         query,
 	                                         &tmp_err);
 	if (tmp_err != NULL)
@@ -1809,9 +1836,9 @@ e_cal_backend_kolab_start_view (ECalBackend *backend,
 	for (it = uid_list; it != NULL; it = g_list_next (it)) {
 		gchar *uid = it->data;
 		ECalComponent *ecalcomp = NULL;
-		ecalcomp = kolab_util_calendar_cache_get_object (priv->cal_cache,
+		ecalcomp = kolab_util_calendar_cache_get_object (E_CAL_BACKEND_SYNC (backend),
+		                                                 priv->cal_cache,
 		                                                 priv->cal_koma,
-		                                                 priv->cal_uri,
 		                                                 uid,
 		                                                 TRUE,
 		                                                 NULL, /* FIXME GCancellable */
@@ -1853,7 +1880,7 @@ e_cal_backend_kolab_start_view (ECalBackend *backend,
 
 	e_data_cal_view_notify_complete (view, view_err);
 
-	g_mutex_unlock (active_cal_views_lock);
+	g_mutex_unlock (&active_cal_views_lock);
 
 	if (view_err != NULL)
 		g_error_free (view_err);
@@ -1862,8 +1889,6 @@ e_cal_backend_kolab_start_view (ECalBackend *backend,
 		g_slist_foreach (iCal_objects, (GFunc) g_free, NULL);
 		g_slist_free (iCal_objects);
 	}
-	if (sourcename != NULL)
-		g_free (sourcename);
 	if (uid_list != NULL)
 		kolab_util_glib_glist_free (uid_list);
 
@@ -1882,13 +1907,13 @@ e_cal_backend_kolab_stop_view (ECalBackend *backend,
 	/* self = E_CAL_BACKEND_KOLAB (backend); */
 	/* priv = E_CAL_BACKEND_KOLAB_PRIVATE (self); */
 
-	g_mutex_lock (active_cal_views_lock);
+	g_mutex_lock (&active_cal_views_lock);
 
 	e_data_cal_view_notify_complete (view, NULL);
 
 	g_object_unref (view); /* ref()d in start_view() */
 
-	g_mutex_unlock (active_cal_views_lock);
+	g_mutex_unlock (&active_cal_views_lock);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -1900,33 +1925,13 @@ e_cal_backend_kolab_init (ECalBackendKolab *backend)
 	ECalBackendKolab *self = E_CAL_BACKEND_KOLAB (backend);
 	ECalBackendKolabPrivate *priv = E_CAL_BACKEND_KOLAB_PRIVATE (self);
 
-	/* We're inside a thread, and each of our siblings
-	 * (other configured ECalBackendKolab instances) is
-	 * so as well. Depending on how the threads are
-	 * started, checking for lock existence (and creating
-	 * one if it is not) in *this* place can still be
-	 * racy. Let's hope the threads are started one
-	 * at a time, in which case this solution will work.
-	 * The whole handling of living KolabMailAccess
-	 * instances would better be moved to a separate
-	 * library...
-	 *
-	 */
-	if (koma_objects_lock == NULL)
-		koma_objects_lock = g_mutex_new ();
-	g_mutex_lock (koma_objects_lock);
+	g_mutex_lock (&koma_objects_lock);
 	if (koma_objects == NULL)
 		koma_objects = g_hash_table_new_full (g_direct_hash,
 		                                      g_direct_equal,
 		                                      g_free,
 		                                      g_object_unref);
-	g_mutex_unlock (koma_objects_lock);
-	/* active cal views are shared in the same way,
-	 * so we do the locking for them analogous
-	 * to the KolabMailAccess instances
-	 */
-	if (active_cal_views_lock == NULL)
-		active_cal_views_lock = g_mutex_new ();
+	g_mutex_unlock (&koma_objects_lock);
 
 	g_debug ("%s()[%u] called.", __func__, __LINE__);
 
@@ -1936,7 +1941,6 @@ e_cal_backend_kolab_init (ECalBackendKolab *backend)
 	priv->user_email = NULL;
 	priv->default_zone = NULL;
 	priv->source_type = 0;
-	priv->cal_uri = NULL;
 	priv->mode_switch_err = NULL;
 
 	g_signal_connect (E_BACKEND (backend), "notify::online", G_CALLBACK (cal_backend_kolab_signal_online_cb), NULL);
@@ -1979,8 +1983,6 @@ e_cal_backend_kolab_finalize (GObject *object)
 
 	if (priv->user_email != NULL)
 		g_free (priv->user_email);
-	if (priv->cal_uri != NULL)
-		g_free (priv->cal_uri);
 
 	if (priv->mode_switch_err != NULL) {
 		g_warning ("%s()[%u]: %s",
@@ -1989,7 +1991,7 @@ e_cal_backend_kolab_finalize (GObject *object)
 	}
 
 	G_OBJECT_CLASS (e_cal_backend_kolab_parent_class)->finalize (object);
-} /* e_book_backend_kolab_finalize () */
+} /* e_cal_backend_kolab_finalize () */
 
 /**
  * e_cal_backend_kolab_class_init:
@@ -2033,7 +2035,6 @@ e_cal_backend_kolab_class_init (ECalBackendKolabClass *klass)
 	sync_class->discard_alarm_sync = e_cal_backend_kolab_discard_alarm;
 	sync_class->get_timezone_sync = e_cal_backend_kolab_get_timezone;
 	sync_class->add_timezone_sync = e_cal_backend_kolab_add_timezone;
-	sync_class->authenticate_user_sync = e_cal_backend_kolab_authenticate_user;
 
 } /* e_cal_backend_kolab_class_init () */
 
@@ -2220,7 +2221,7 @@ e_cal_backend_kolab_set_mode (ECalBackend *backend,
 	GError *error = NULL;
 	KolabMailAccessOpmodeID koma_mode = KOLAB_MAIL_ACCESS_OPMODE_INVAL;
 	KolabMailAccessOpmodeID tmp_mode = KOLAB_MAIL_ACCESS_OPMODE_INVAL;
-	gchar *sourcename = NULL;
+	const gchar *foldername;
 	KolabSettingsHandler *ksettings = NULL;
 	gboolean ok;
 
@@ -2271,9 +2272,9 @@ e_cal_backend_kolab_set_mode (ECalBackend *backend,
 	if (ok && (koma_mode < KOLAB_MAIL_ACCESS_OPMODE_ONLINE))
 		return;
 
-	sourcename = kolab_util_backend_get_relative_path_from_uri (priv->cal_uri);
+	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 	ok = kolab_mail_access_source_fbtrigger_needed (priv->cal_koma,
-	                                                sourcename,
+	                                                foldername,
 	                                                &error);
 	if (error != NULL)
 		{
@@ -2281,16 +2282,14 @@ e_cal_backend_kolab_set_mode (ECalBackend *backend,
 			           __func__, __LINE__, error->message);
 			g_error_free (error);
 			error = NULL;
-			goto cleanup;
+			return;
 		}
 	if (ok) {
 		ksettings = kolab_mail_access_get_settings_handler (priv->cal_koma);
 		kolab_util_calendar_toggle_pfb_trigger (ksettings,
-		                                        sourcename);
+		                                        foldername);
 		g_object_unref (ksettings);
 	}
- cleanup:
-	g_free (sourcename);
 } /* e_cal_backend_kolab_set_mode () */
 
 /**
