@@ -32,6 +32,7 @@
 #include <gdk/gdk.h>
 #include <glib/gi18n-lib.h>
 
+#include "e-kolab-plugin-util.h"
 #include "e-kolab-backend-sync-conflict.h"
 
 /*----------------------------------------------------------------------------*/
@@ -95,22 +96,6 @@ kolab_backend_sync_conflict_ui_grid_new (void)
 	return grid;
 }
 
-static GtkWidget*
-kolab_backend_sync_conflict_ui_label_new (const gchar *text,
-                                          gboolean add_bottom_space)
-{
-	GtkWidget *label = gtk_label_new (text);
-
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-
-	if (add_bottom_space)
-		gtk_widget_set_margin_bottom (label, 5);
-
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 1.0);
-
-	return label;
-}
-
 static KolabBackendSyncConflictUIData*
 kolab_backend_sync_conflict_ui_new (void)
 {
@@ -158,60 +143,60 @@ kolab_backend_sync_conflict_ui_new (void)
 	row = 0;
 
 	/* conflict folder name */
-	label = kolab_backend_sync_conflict_ui_label_new (C_("Sync Conflict Resolution",
-	                                                     "Conflict in folder:"),
-	                                                  TRUE);
+	label = e_kolab_plugin_util_ui_label_new (C_("Sync Conflict Resolution",
+	                                             "Conflict in folder:"),
+	                                          TRUE);
 	gtk_grid_attach (grid, label, 0, row, 1, 1);
-	label = kolab_backend_sync_conflict_ui_label_new ("INBOX/Calendar" /* FIXME add folder path here */,
-	                                                  TRUE);
+	label = e_kolab_plugin_util_ui_label_new ("INBOX/Calendar" /* FIXME add folder path here */,
+	                                          TRUE);
 	uidata->widgets->lbl_folder_name = label;
 	gtk_grid_attach (grid, label, 1, row, 1, 1);
 
 	row++;
 
 	/* local object - subject */
-	label = kolab_backend_sync_conflict_ui_label_new (C_("Sync Conflict Resolution",
-	                                                     "Local entry:"),
-	                                                  FALSE);
+	label = e_kolab_plugin_util_ui_label_new (C_("Sync Conflict Resolution",
+	                                             "Local entry:"),
+	                                          FALSE);
 	gtk_grid_attach (grid, label, 0, row, 1, 1);
-	label = kolab_backend_sync_conflict_ui_label_new ("Meeting" /* FIXME add subject here */,
-	                                                  FALSE);
+	label = e_kolab_plugin_util_ui_label_new ("Meeting" /* FIXME add subject here */,
+	                                          FALSE);
 	uidata->widgets->lbl_local_subject = label;
 	gtk_grid_attach (grid, label, 1, row, 1, 1);
 
 	row++;
 
 	/* local object - last modified */
-	label = kolab_backend_sync_conflict_ui_label_new (C_("Sync Conflict Resolution",
-	                                                     "Last modified:"),
-	                                                  TRUE);
+	label = e_kolab_plugin_util_ui_label_new (C_("Sync Conflict Resolution",
+	                                             "Last modified:"),
+	                                          TRUE);
 	gtk_grid_attach (grid, label, 0, row, 1, 1);
-	label = kolab_backend_sync_conflict_ui_label_new ("2012-06-01 18:05" /* FIXME add modtime here */,
-	                                                  TRUE);
+	label = e_kolab_plugin_util_ui_label_new ("2012-06-01 18:05" /* FIXME add modtime here */,
+	                                          TRUE);
 	uidata->widgets->lbl_local_modtime = label;
 	gtk_grid_attach (grid, label, 1, row, 1, 1);
 
 	row++;
 
 	/* remote object - subject */
-	label = kolab_backend_sync_conflict_ui_label_new (C_("Sync Conflict Resolution",
-	                                                     "Remote entry:"),
-	                                                  FALSE);
+	label = e_kolab_plugin_util_ui_label_new (C_("Sync Conflict Resolution",
+	                                             "Remote entry:"),
+	                                          FALSE);
 	gtk_grid_attach (grid, label, 0, row, 1, 1);
-	label = kolab_backend_sync_conflict_ui_label_new ("Meeting - modified" /* FIXME add subject here */,
-	                                                  FALSE);
+	label = e_kolab_plugin_util_ui_label_new ("Meeting - modified" /* FIXME add subject here */,
+	                                          FALSE);
 	uidata->widgets->lbl_remote_subject = label;
 	gtk_grid_attach (grid, label, 1, row, 1, 1);
 
 	row++;
 
 	/* remote object - last modified */
-	label = kolab_backend_sync_conflict_ui_label_new (C_("Sync Conflict Resolution",
-	                                                     "Last modified:"),
-	                                                  TRUE);
+	label = e_kolab_plugin_util_ui_label_new (C_("Sync Conflict Resolution",
+	                                             "Last modified:"),
+	                                          TRUE);
 	gtk_grid_attach (grid, label, 0, row, 1, 1);
-	label = kolab_backend_sync_conflict_ui_label_new ("2012-06-01 18:05" /* FIXME add modtime here */,
-	                                                  TRUE);
+	label = e_kolab_plugin_util_ui_label_new ("2012-06-01 18:05" /* FIXME add modtime here */,
+	                                          TRUE);
 	uidata->widgets->lbl_remote_modtime = label;
 	gtk_grid_attach (grid, label, 1, row, 1, 1);
 
