@@ -115,6 +115,8 @@ e_kolab_folder_metadata_ui_free (KolabFolderMetaUIData *uidata)
 	kolab_data_folder_metadata_free (uidata->metadata);
 	if (uidata->selected_folder != NULL)
 		g_free (uidata->selected_folder);
+	if (uidata->selected_source != NULL)
+		g_free (uidata->selected_source);
 
 	g_free (uidata);
 }
