@@ -93,7 +93,8 @@ kolab_folder_permissions_ui_edit_dialog_cb (KolabFolderPermUIData *uidata)
 	content = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 	gtk_container_set_border_width (GTK_CONTAINER (content), 6);
 
-	widget = e_kolab_plugin_util_ui_selected_folder_widget (uidata->selected_folder);
+	widget = e_kolab_plugin_util_ui_selected_folder_widget (uidata->selected_folder,
+	                                                        uidata->selected_source);
 	gtk_container_add (GTK_CONTAINER (content), widget);
 
 	widget = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
@@ -390,6 +391,8 @@ e_kolab_folder_permissions_ui_free (KolabFolderPermUIData *uidata)
 	kolab_data_folder_permissions_free (uidata->permissions);
 	if (uidata->selected_folder != NULL)
 		g_free (uidata->selected_folder);
+	if (uidata->selected_source != NULL)
+		g_free (uidata->selected_source);
 
 	g_free (uidata);
 }
