@@ -37,7 +37,12 @@
 /*----------------------------------------------------------------------------*/
 
 GtkWidget*
-e_kolab_plugin_util_ui_selected_folder_widget (const gchar *foldername);
+e_kolab_plugin_util_ui_label_new (const gchar *text,
+                                  gboolean add_bottom_space);
+
+GtkWidget*
+e_kolab_plugin_util_ui_selected_folder_widget (const gchar *foldername,
+                                               const gchar *sourcename);
 
 /*----------------------------------------------------------------------------*/
 
