@@ -30,14 +30,14 @@
 #include <glib/gi18n-lib.h>
 
 #include <camel/camel-kolab-imapx-provider.h>
-#include <camel/camel-kolab-imapx-store.h>
-#include <camel/camel-kolab-session.h>
 
 #include <libekolabutil/camel-system-headers.h>
 #include <libekolabutil/kolab-util-glib.h>
 #include <libekolabutil/kolab-util-error.h>
 #include <libekolabutil/kolab-util-camel.h>
 
+#include "camel-kolab-session.h"
+#include "camel-kolab-imapx-store.h"
 #include "kolab-util-backend.h"
 #include "kolab-mail-summary.h"
 #include "kolab-types.h"
@@ -709,105 +709,23 @@ kolab_mail_imap_client_configure (KolabMailImapClient *self,
 	return TRUE;
 }
 
-static gboolean
-kolab_mail_imap_client_configure_store_settings (KolabMailImapClient *self,
-                                                 GError **err)
+static void
+kolab_mail_imap_client_configure_store_settings (KolabMailImapClient *self)
 {
 	KolabMailImapClientPrivate *priv = NULL;
 	CamelService *service = NULL;
-	CamelSettings *camel_settings = NULL;
-	CamelURL *camel_url = NULL;
-	CamelNetworkSecurityMethod security_method = CAMEL_NETWORK_SECURITY_METHOD_STARTTLS_ON_STANDARD_PORT;
-	guint16 port = 0;
-	KolabTLSVariantID tlsvariant = KOLAB_TLS_VARIANT_NONE;
-	GError *tmp_err = NULL;
-
-	/* TODO rework this function for new CamelSettings API
-	 *
-	 * Set the details for the settings object directly
-	 * instead of using the camel_settings_load_from_url()
-	 * function, which is a transient one only and
-	 * scheduled for removal
-	 */
+	CamelKolabIMAPXSettings *settings;
 
 	g_assert (KOLAB_IS_MAIL_IMAP_CLIENT (self));
-	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_MAIL_IMAP_CLIENT_PRIVATE (self);
 
-	/* FIXME this is a transient thing, we should set
-	 *       the CamelSettings values directly from
-	 *       KolabSettingsHandler
-	 */
-	camel_url = \
-		kolab_util_backend_camel_url_new_from_settings (priv->ksettings,
-		                                                &tmp_err);
-	if (camel_url == NULL) {
-		g_propagate_error (err, tmp_err);
-		return FALSE;
-	}
-
-	/* create new settings object for service */
 	service = CAMEL_SERVICE (priv->store);
-	camel_service_set_settings (service, NULL);
-	camel_settings = camel_service_get_settings (service);
+	settings = kolab_settings_handler_get_camel_settings (priv->ksettings);
 
-	camel_settings_load_from_url (camel_settings, camel_url);
-
-	/* get the details not (or no longer) covered by
-	 * CamelURL. Should be done for all details this
-	 * way, instead of using the (deprecated) CamelURL
-	 * for this
-	 */
-
-	/* security and port settings  */
-	tlsvariant = kolab_settings_handler_get_uint_field (priv->ksettings,
-	                                                    KOLAB_SETTINGS_HANDLER_UINT_FIELD_TLS_VARIANT,
-	                                                    &tmp_err);
-	if (tmp_err != NULL) {
-		camel_url_free (camel_url);
-		g_propagate_error (err, tmp_err);
-		return FALSE;
-	}
-
-	switch (tlsvariant) {
-	case KOLAB_TLS_VARIANT_NONE:
-		security_method = CAMEL_NETWORK_SECURITY_METHOD_NONE;
-		port = (guint16)kolab_settings_handler_get_int_field (priv->ksettings,
-		                                                      KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAP_PORT,
-		                                                      &tmp_err);
-		break;
-	case KOLAB_TLS_VARIANT_SSL:
-		security_method = CAMEL_NETWORK_SECURITY_METHOD_SSL_ON_ALTERNATE_PORT;
-		port = (guint16)kolab_settings_handler_get_int_field (priv->ksettings,
-		                                                      KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAPS_PORT,
-		                                                      &tmp_err);
-		break;
-	case KOLAB_TLS_VARIANT_STARTTLS:
-	default:
-		security_method = CAMEL_NETWORK_SECURITY_METHOD_STARTTLS_ON_STANDARD_PORT;
-		port = (guint16)kolab_settings_handler_get_int_field (priv->ksettings,
-		                                                      KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAP_PORT,
-		                                                      &tmp_err);
-	}
-	if (tmp_err != NULL) {
-		camel_url_free (camel_url);
-		g_propagate_error (err, tmp_err);
-		return FALSE;
-	}
-
-	/* set details */
-	camel_network_settings_set_security_method (CAMEL_NETWORK_SETTINGS (camel_settings),
-	                                            security_method);
-	camel_network_settings_set_port (CAMEL_NETWORK_SETTINGS (camel_settings),
-	                                 port);
-
-	/* re-set the settings for our service (store) */
-	camel_service_set_settings (service, camel_settings);
-
-	camel_url_free (camel_url);
-
-	return TRUE;
+	/* The CamelKolabIMAPXSettings held by CamelSettingsHandler
+	 * is authoritative, so just plug it into the CamelService. */
+	camel_service_set_settings (service, CAMEL_SETTINGS (settings));
 }
 
 gboolean
@@ -882,12 +800,7 @@ kolab_mail_imap_client_bringup (KolabMailImapClient *self,
 	}
 
 	/* configure the service with settings from KolabSettingsHandler */
-	ok = kolab_mail_imap_client_configure_store_settings (self,
-	                                                      &tmp_err);
-	if (! ok) {
-		g_propagate_error (err, tmp_err);
-		return FALSE;
-	}
+	kolab_mail_imap_client_configure_store_settings (self);
 
 	/* set offline state */
 	ok = camel_offline_store_set_online_sync (CAMEL_OFFLINE_STORE (priv->store),
@@ -970,6 +883,7 @@ kolab_mail_imap_client_go_online (KolabMailImapClient *self,
                                   GError **err)
 {
 	KolabMailImapClientPrivate *priv = NULL;
+	CamelKolabIMAPXSettings *settings;
 	const gchar *tmp_str = NULL;
 	GError *tmp_err = NULL;
 	gboolean ok = FALSE;
@@ -998,13 +912,8 @@ kolab_mail_imap_client_go_online (KolabMailImapClient *self,
 	camel_kolab_session_set_password (priv->session, tmp_str);
 
 	/* set the TPM token pin (we may get it late in the book backend) */
-	tmp_str = kolab_settings_handler_get_char_field (priv->ksettings,
-	                                                 KOLAB_SETTINGS_HANDLER_CHAR_FIELD_PKCS11_USER_PIN,
-	                                                 &tmp_err);
-	if (tmp_err != NULL) {
-		g_propagate_error (err, tmp_err);
-		return FALSE;
-	}
+	settings = kolab_settings_handler_get_camel_settings (priv->ksettings);
+	tmp_str = camel_kolab_imapx_settings_get_pkcs11_pin (settings);
 	camel_kolab_session_set_token_pin (priv->session, tmp_str);
 
 	/* remove local CamelFolder object */
