@@ -247,10 +247,29 @@ kolab_mail_mime_builder_conv_new_from_camel (KolabMailMimeBuilder *self,
 	g_debug ("%s: number of parts: %i", __func__, nparts);
 
 	if (nparts < KOLAB_MAIL_MIME_PARTS_MIN) {
+		const gchar *errmsg = NULL;
+		/* Hint to translators:
+		 *
+		 * The minimum number of mime parts expected here
+		 * is subject to the Kolab format specification.
+		 * The Kolab2 format mandates a minimum number of
+		 * two mime parts, the first being a descriptive
+		 * text, the second being the Kolab XML mime part.
+		 * More mime parts may follow (e.g. attachments).
+		 * Unless the Kolab format specification changes,
+		 * KOLAB_MAIL_MIME_PARTS_MIN will therefore be 2.
+		 *
+		 * The singular form of this message will never
+		 * be displayed.
+		 */
+		/* xgettext: range: 2..2 */
+		errmsg = ngettext ("Mail message does not have the expected minimum of %i mime part, ignoring",
+		                   "Mail message does not have the expected minimum of %i mime parts, ignoring",
+		                   KOLAB_MAIL_MIME_PARTS_MIN);
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_KOLAB,
-		             _("Mail message does not have the expected minimum of %i mime parts, ignoring"),
+		             errmsg,
 		             KOLAB_MAIL_MIME_PARTS_MIN);
 		return NULL;
 	}
