@@ -49,6 +49,14 @@
 #define KOLAB_IMAP_CLIENT_DUMMY_FROM_NAME  "Nobody"
 #define KOLAB_IMAP_CLIENT_DUMMY_FROM_ADDR  "nobody@localhost.localdomain"
 
+/* default fallback TCP ports */
+#define KOLAB_SERVER_IMAP_PORT  143
+#define KOLAB_SERVER_IMAPS_PORT 993
+#define KOLAB_SERVER_HTTP_PORT  80
+#define KOLAB_SERVER_HTTPS_PORT 443
+#define KOLAB_SERVER_LDAP_PORT  389
+#define KOLAB_SERVER_LDAPS_PORT 636
+
 /*----------------------------------------------------------------------------*/
 /* Camel init/shutdown */
 
