@@ -55,12 +55,11 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#include <camel/camel-kolab-stream.h>
-
 /* HTTP lib specifics */
 #include <libsoup/soup-gnome.h>
 #include <curl/curl.h>
 
+#include "camel-kolab-stream.h"
 #include "camel-system-headers.h"
 #include "kolab-util-http.h"
 
